@@ -26,7 +26,7 @@
  * <refsect2>
  * <title>Example launch line</title>
  * |[
- * gst-launch videotestsrc num-buffers=50 ! video/x-raw-yuv, framerate='(fraction)'5/1 ! jpegenc ! avimux ! filesink location=mjpeg.avi
+ * gst-launch-1.0 videotestsrc num-buffers=50 ! video/x-raw, framerate='(fraction)'5/1 ! jpegenc ! avimux ! filesink location=mjpeg.avi
  * ]| a pipeline to mux 5 JPEG frames per second into a 10 sec. long motion jpeg
  * avi.
  * </refsect2>
@@ -152,7 +152,7 @@ gst_jpegenc_class_init (GstJpegEncClass * klass)
       gst_static_pad_template_get (&gst_jpegenc_sink_pad_template));
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&gst_jpegenc_src_pad_template));
-  gst_element_class_set_details_simple (element_class, "JPEG image encoder",
+  gst_element_class_set_metadata (element_class, "JPEG image encoder",
       "Codec/Encoder/Image",
       "Encode images in JPEG format", "Wim Taymans <wim.taymans@tvd.be>");
 
@@ -179,7 +179,7 @@ ensure_memory (GstJpegEnc * jpegenc)
   GstMapInfo map;
   gsize old_size, desired_size, new_size;
   guint8 *new_data;
-  static GstAllocationParams params = { 0, 0, 0, 3, };
+  static GstAllocationParams params = { 0, 3, 0, 0, };
 
   old_size = jpegenc->output_map.size;
   if (old_size == 0)
@@ -248,6 +248,8 @@ gst_jpegenc_term_destination (j_compress_ptr cinfo)
 
   gst_video_frame_unmap (&jpegenc->current_vframe);
 
+  GST_VIDEO_CODEC_FRAME_SET_SYNC_POINT (jpegenc->current_frame);
+
   gst_video_encoder_finish_frame (GST_VIDEO_ENCODER (jpegenc),
       jpegenc->current_frame);
   jpegenc->current_frame = NULL;
@@ -531,7 +533,7 @@ invalid_frame:
 static gboolean
 gst_jpegenc_propose_allocation (GstVideoEncoder * encoder, GstQuery * query)
 {
-  gst_query_add_allocation_meta (query, GST_VIDEO_META_API_TYPE);
+  gst_query_add_allocation_meta (query, GST_VIDEO_META_API_TYPE, NULL);
 
   return GST_VIDEO_ENCODER_CLASS (parent_class)->propose_allocation (encoder,
       query);
