@@ -29,7 +29,7 @@
  * <refsect2>
  * <title>Example launch line</title>
  * |[
- * gst-launch -v audiotestsrc ! audioconvert ! monoscope ! ffmpegcolorspace ! ximagesink
+ * gst-launch-1.0 -v audiotestsrc ! audioconvert ! monoscope ! videoconvert ! ximagesink
  * ]|
  * </refsect2>
  */
@@ -214,7 +214,7 @@ gst_monoscope_src_setcaps (GstMonoscope * monoscope, GstCaps * caps)
 
   monoscope->visstate = monoscope_init (monoscope->width, monoscope->height);
 
-  res = gst_pad_push_event (monoscope->srcpad, gst_event_new_caps (caps));
+  res = gst_pad_set_caps (monoscope->srcpad, caps);
 
   return res && (monoscope->visstate != NULL);
 }
