@@ -31,7 +31,7 @@
  * <refsect2>
  * <title>Sample pipelines</title>
  * |[
- * gst-launch -v videotestsrc pattern=1 ! smpte name=s border=20000 type=234 duration=2000000000 ! ffmpegcolorspace ! ximagesink videotestsrc ! s.
+ * gst-launch-1.0 -v videotestsrc pattern=1 ! smpte name=s border=20000 type=234 duration=2000000000 ! videoconvert ! ximagesink videotestsrc ! s.
  * ]| A pipeline to demonstrate the smpte transition.
  * It shows a pinwheel transition a from a snow videotestsrc to an smpte
  * pattern videotestsrc. The transition will take 2 seconds to complete. The
@@ -84,7 +84,6 @@ enum
 #define DEFAULT_PROP_TYPE	1
 #define DEFAULT_PROP_BORDER	0
 #define DEFAULT_PROP_DEPTH	16
-#define DEFAULT_PROP_FPS	0.
 #define DEFAULT_PROP_DURATION	GST_SECOND
 #define DEFAULT_PROP_INVERT   FALSE
 
@@ -94,12 +93,12 @@ enum
   PROP_TYPE,
   PROP_BORDER,
   PROP_DEPTH,
-  PROP_FPS,
   PROP_DURATION,
   PROP_INVERT,
   PROP_LAST,
 };
 
+/* FIXME: should use video meta etc. */
 #define I420_Y_ROWSTRIDE(width) (GST_ROUND_UP_4(width))
 #define I420_U_ROWSTRIDE(width) (GST_ROUND_UP_8(width)/2)
 #define I420_V_ROWSTRIDE(width) ((GST_ROUND_UP_8(I420_Y_ROWSTRIDE(width)))/2)
@@ -185,11 +184,6 @@ gst_smpte_class_init (GstSMPTEClass * klass)
       g_param_spec_enum ("type", "Type", "The type of transition to use",
           GST_TYPE_SMPTE_TRANSITION_TYPE, DEFAULT_PROP_TYPE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-  g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_FPS,
-      g_param_spec_float ("fps", "FPS",
-          "Frames per second if no input files are given (deprecated)", 0.,
-          G_MAXFLOAT, DEFAULT_PROP_FPS,
-          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_BORDER,
       g_param_spec_int ("border", "Border",
           "The border width of the transition", 0, G_MAXINT,
@@ -288,9 +282,6 @@ gst_smpte_setcaps (GstPad * pad, GstCaps * caps)
   smpte->fps_num = GST_VIDEO_INFO_FPS_N (&vinfo);
   smpte->fps_denom = GST_VIDEO_INFO_FPS_D (&vinfo);
 
-  /* for backward compat, we store these here */
-  smpte->fps = ((gdouble) smpte->fps_num) / smpte->fps_denom;
-
   /* figure out the duration in frames */
   smpte->end_position = gst_util_uint64_scale (smpte->duration,
       smpte->fps_num, GST_SECOND * smpte->fps_denom);
@@ -366,11 +357,10 @@ gst_smpte_init (GstSMPTE * smpte)
       GST_DEBUG_FUNCPTR (gst_smpte_sink_event), smpte);
 
   gst_collect_pads_add_pad (smpte->collect, smpte->sinkpad1,
-      sizeof (GstCollectData));
+      sizeof (GstCollectData), NULL, TRUE);
   gst_collect_pads_add_pad (smpte->collect, smpte->sinkpad2,
-      sizeof (GstCollectData));
+      sizeof (GstCollectData), NULL, TRUE);
 
-  smpte->fps = DEFAULT_PROP_FPS;
   smpte->type = DEFAULT_PROP_TYPE;
   smpte->border = DEFAULT_PROP_BORDER;
   smpte->depth = DEFAULT_PROP_DEPTH;
@@ -397,6 +387,7 @@ gst_smpte_reset (GstSMPTE * smpte)
   smpte->height = -1;
   smpte->position = 0;
   smpte->end_position = 0;
+  smpte->send_stream_start = TRUE;
 }
 
 static void
@@ -478,6 +469,15 @@ gst_smpte_collected (GstCollectPads * pads, GstSMPTE * smpte)
       !gst_pad_has_current_caps (smpte->sinkpad2))
     goto not_negotiated;
 
+  if (smpte->send_stream_start) {
+    gchar s_id[32];
+
+    /* stream-start (FIXME: create id based on input ids) */
+    g_snprintf (s_id, sizeof (s_id), "smpte-%08x", g_random_int ());
+    gst_pad_push_event (smpte->srcpad, gst_event_new_stream_start (s_id));
+    smpte->send_stream_start = FALSE;
+  }
+
   ts = gst_util_uint64_scale_int (smpte->position * GST_SECOND,
       smpte->fps_denom, smpte->fps_num);
 
@@ -598,9 +598,6 @@ gst_smpte_set_property (GObject * object, guint prop_id,
     case PROP_BORDER:
       smpte->border = g_value_get_int (value);
       break;
-    case PROP_FPS:
-      smpte->fps = g_value_get_float (value);
-      break;
     case PROP_DEPTH:
       smpte->depth = g_value_get_int (value);
       break;
@@ -628,9 +625,6 @@ gst_smpte_get_property (GObject * object, guint prop_id,
     case PROP_TYPE:
       g_value_set_enum (value, smpte->type);
       break;
-    case PROP_FPS:
-      g_value_set_float (value, smpte->fps);
-      break;
     case PROP_BORDER:
       g_value_set_int (value, smpte->border);
       break;
